/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 35 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"

#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 44 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 83 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 86 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 91 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 94 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 97 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 100 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 103 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 106 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 109 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 112 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 115 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 118 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 121 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 124 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 127 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 130 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 133 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 136 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQAbstractSeries.cpp"


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_type, "type(self) -> QAbstractSeries.SeriesType");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_type(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp))
        {
            ::QtCharts::QAbstractSeries::SeriesType sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractSeries, sipName_type);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QAbstractSeries_SeriesType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_type, doc_QtCharts_QAbstractSeries_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_setName, "setName(self, name: str|None)");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_setName(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_setName, doc_QtCharts_QAbstractSeries_setName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_name, "name(self) -> str");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_name(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_name, doc_QtCharts_QAbstractSeries_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_setVisible, "setVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_setVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_setVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractSeries *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp, &a0))
        {
            sipCpp->setVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_setVisible, doc_QtCharts_QAbstractSeries_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_isVisible, "isVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_isVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_isVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_isVisible, doc_QtCharts_QAbstractSeries_isVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_chart, "chart(self) -> QChart|None");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_chart(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_chart(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp))
        {
            ::QtCharts::QChart*sipRes;

            sipRes = sipCpp->chart();

            return sipConvertFromType(sipRes, sipType_QtCharts_QChart, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_chart, doc_QtCharts_QAbstractSeries_chart);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_show, "show(self)");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_show(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_show(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp))
        {
            sipCpp->show();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_show, doc_QtCharts_QAbstractSeries_show);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_hide, "hide(self)");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_hide(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_hide(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp))
        {
            sipCpp->hide();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_hide, doc_QtCharts_QAbstractSeries_hide);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_opacity, "opacity(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_opacity(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_opacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->opacity();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_opacity, doc_QtCharts_QAbstractSeries_opacity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_setOpacity, "setOpacity(self, opacity: float)");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_setOpacity(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_setOpacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp, &a0))
        {
            sipCpp->setOpacity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_setOpacity, doc_QtCharts_QAbstractSeries_setOpacity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_attachAxis, "attachAxis(self, axis: QAbstractAxis|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_attachAxis(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_attachAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractAxis* a0;
        ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp, sipType_QtCharts_QAbstractAxis, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->attachAxis(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_attachAxis, doc_QtCharts_QAbstractSeries_attachAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_detachAxis, "detachAxis(self, axis: QAbstractAxis|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_detachAxis(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_detachAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractAxis* a0;
        ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp, sipType_QtCharts_QAbstractAxis, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->detachAxis(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_detachAxis, doc_QtCharts_QAbstractSeries_detachAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_attachedAxes, "attachedAxes(self) -> list[QAbstractAxis]");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_attachedAxes(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_attachedAxes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp))
        {
            QList< ::QtCharts::QAbstractAxis*>*sipRes;

            sipRes = new QList< ::QtCharts::QAbstractAxis*>(sipCpp->attachedAxes());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtCharts_QAbstractAxis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_attachedAxes, doc_QtCharts_QAbstractSeries_attachedAxes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_setUseOpenGL, "setUseOpenGL(self, enable: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_setUseOpenGL(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_setUseOpenGL(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QAbstractSeries *sipCpp;

        static const char *sipKwdList[] = {
            sipName_enable,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp, &a0))
        {
            sipCpp->setUseOpenGL(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_setUseOpenGL, doc_QtCharts_QAbstractSeries_setUseOpenGL);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QAbstractSeries_useOpenGL, "useOpenGL(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QAbstractSeries_useOpenGL(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QAbstractSeries_useOpenGL(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QAbstractSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QAbstractSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->useOpenGL();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSeries, sipName_useOpenGL, doc_QtCharts_QAbstractSeries_useOpenGL);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QAbstractSeries(void *, const sipTypeDef *);}
static void *cast_QtCharts_QAbstractSeries(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QAbstractSeries *sipCpp = reinterpret_cast< ::QtCharts::QAbstractSeries *>(sipCppV);

    if (targetType == sipType_QtCharts_QAbstractSeries)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QAbstractSeries(void *, int);}
static void release_QtCharts_QAbstractSeries(void *sipCppV, int)
{
    ::QtCharts::QAbstractSeries *sipCpp = reinterpret_cast< ::QtCharts::QAbstractSeries *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QtCharts_QAbstractSeries(sipSimpleWrapper *);}
static void dealloc_QtCharts_QAbstractSeries(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QAbstractSeries(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QAbstractSeries[] = {{10, 0, 1}};


static PyMethodDef methods_QtCharts_QAbstractSeries[] = {
    {sipName_attachAxis, meth_QtCharts_QAbstractSeries_attachAxis, METH_VARARGS, doc_QtCharts_QAbstractSeries_attachAxis},
    {sipName_attachedAxes, meth_QtCharts_QAbstractSeries_attachedAxes, METH_VARARGS, doc_QtCharts_QAbstractSeries_attachedAxes},
    {sipName_chart, meth_QtCharts_QAbstractSeries_chart, METH_VARARGS, doc_QtCharts_QAbstractSeries_chart},
    {sipName_detachAxis, meth_QtCharts_QAbstractSeries_detachAxis, METH_VARARGS, doc_QtCharts_QAbstractSeries_detachAxis},
    {sipName_hide, meth_QtCharts_QAbstractSeries_hide, METH_VARARGS, doc_QtCharts_QAbstractSeries_hide},
    {sipName_isVisible, meth_QtCharts_QAbstractSeries_isVisible, METH_VARARGS, doc_QtCharts_QAbstractSeries_isVisible},
    {sipName_name, meth_QtCharts_QAbstractSeries_name, METH_VARARGS, doc_QtCharts_QAbstractSeries_name},
    {sipName_opacity, meth_QtCharts_QAbstractSeries_opacity, METH_VARARGS, doc_QtCharts_QAbstractSeries_opacity},
    {sipName_setName, meth_QtCharts_QAbstractSeries_setName, METH_VARARGS, doc_QtCharts_QAbstractSeries_setName},
    {sipName_setOpacity, meth_QtCharts_QAbstractSeries_setOpacity, METH_VARARGS, doc_QtCharts_QAbstractSeries_setOpacity},
    {sipName_setUseOpenGL, SIP_MLMETH_CAST(meth_QtCharts_QAbstractSeries_setUseOpenGL), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractSeries_setUseOpenGL},
    {sipName_setVisible, SIP_MLMETH_CAST(meth_QtCharts_QAbstractSeries_setVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QAbstractSeries_setVisible},
    {sipName_show, meth_QtCharts_QAbstractSeries_show, METH_VARARGS, doc_QtCharts_QAbstractSeries_show},
    {sipName_type, meth_QtCharts_QAbstractSeries_type, METH_VARARGS, doc_QtCharts_QAbstractSeries_type},
    {sipName_useOpenGL, meth_QtCharts_QAbstractSeries_useOpenGL, METH_VARARGS, doc_QtCharts_QAbstractSeries_useOpenGL}
};

static sipEnumMemberDef enummembers_QtCharts_QAbstractSeries[] = {
    {sipName_SeriesTypeArea, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeArea), 14},
    {sipName_SeriesTypeBar, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeBar), 14},
    {sipName_SeriesTypeBoxPlot, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeBoxPlot), 14},
    {sipName_SeriesTypeCandlestick, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeCandlestick), 14},
    {sipName_SeriesTypeHorizontalBar, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeHorizontalBar), 14},
    {sipName_SeriesTypeHorizontalPercentBar, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeHorizontalPercentBar), 14},
    {sipName_SeriesTypeHorizontalStackedBar, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeHorizontalStackedBar), 14},
    {sipName_SeriesTypeLine, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeLine), 14},
    {sipName_SeriesTypePercentBar, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypePercentBar), 14},
    {sipName_SeriesTypePie, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypePie), 14},
    {sipName_SeriesTypeScatter, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeScatter), 14},
    {sipName_SeriesTypeSpline, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeSpline), 14},
    {sipName_SeriesTypeStackedBar, static_cast<int>(::QtCharts::QAbstractSeries::SeriesTypeStackedBar), 14},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QAbstractSeries[] = {
    {"useOpenGLChanged()", "\1useOpenGLChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"opacityChanged()", "\1opacityChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"visibleChanged()", "\1visibleChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"nameChanged()", "\1nameChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QAbstractSeries = {
    &::QtCharts::QAbstractSeries::staticMetaObject,
    0,
    signals_QtCharts_QAbstractSeries,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QAbstractSeries = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QAbstractSeries,
        SIP_NULLPTR,
        &plugin_QtCharts_QAbstractSeries,
    },
    {
        sipNameNr_QAbstractSeries,
        {0, 0, 1},
        15, methods_QtCharts_QAbstractSeries,
        13, enummembers_QtCharts_QAbstractSeries,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QtCharts_QAbstractSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QAbstractSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QtCharts_QAbstractSeries,
    cast_QtCharts_QAbstractSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
